#
# spec file for package cargo
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2016 Michal Vyskocil, michal.vyskocil@opensuse.org
# Copyright (c) 2016 Kristoffer Gronlund, kgronlund@suse.com
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global prev_rustc 1.16.0
%global curr_rustc 1.17.0
%global prev_version 0.17.0
%global pkg_version 0_18
%global rel_version 0.18.0

%global abi gnu
%ifarch s390x
%global _arch s390x
%endif
%ifarch armv7hl
%global _arch armv7
%global abi gnueabihf
%endif
%ifarch ppc64
%global _arch powerpc64
%endif
%ifarch ppc64le
%global _arch powerpc64le
%endif
%ifarch x86_64
%global _arch x86_64
%endif
%ifarch %{ix86}
%global _arch i586
%endif
%global rust_triple %{_arch}-unknown-linux-%{abi}

%bcond_with bootstrap
Name:           cargo
Version:        %{rel_version}
Release:        1.6
Summary:        The Rust package manager
License:        MIT or Apache-2.0
Group:          Development/Languages/Other
Url:            https://github.com/rust-lang/cargo
Source0:        cargo-%{version}.tar.gz
Source1:        vendor.tar.xz

# There are no successful builds for less than TW or Leap 42.2, so bootstrap
# until such time that there is.
%if %{with bootstrap} || (0%{?suse_version} < 1330 && 0%{?sle_version} < 120200)
BuildRequires:  cargo-bootstrap == %{prev_version}
BuildRequires:  rust == %{prev_rustc}
BuildRequires:  rust-std == %{prev_rustc}
%else
BuildRequires:  cargo <= %{version}
BuildRequires:  cargo >= %{prev_version}
BuildRequires:  rust <= %{curr_rustc}
BuildRequires:  rust >= %{prev_rustc}
BuildRequires:  rust-std <= %{curr_rustc}
BuildRequires:  rust-std >= %{prev_rustc}
%endif
BuildRequires:  cmake
BuildRequires:  curl
BuildRequires:  git
BuildRequires:  libcurl-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libssh-devel
BuildRequires:  zlib-devel
ExclusiveArch:  %{ix86} x86_64 %{arm} aarch64 ppc64 ppc64le s390x

Conflicts:      otherproviders(cargo)
Conflicts:      cargo-bootstrap

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Cargo downloads your Rust project’s dependencies and compiles your project.

%prep
%setup -q -n cargo-%{version}
%setup -q -D -T -a 1 -n cargo-%{version}
mkdir cargo-home
cat >cargo-home/config <<EOF
[source.crates-io]
registry = 'https://github.com/rust-lang/crates.io-index'
replace-with = 'vendored-sources'
[source.vendored-sources]
directory = './vendor'
EOF

%build
export CARGO_HOME=`pwd`/cargo-home/
%configure --disable-option-checking \
    --build=%{rust_triple} \
    --host=%{rust_triple} \
    --target=%{rust_triple} \
    --local-rust-root=%{_prefix} \
    --prefix=%{_prefix} \
    --libdir=%{_libdir}
cargo build --release %{?_smp_mflags}

%install
mkdir build
export CARGO_HOME=`pwd`/cargo-home/
cargo install --root=build
mkdir -p %{buildroot}%{_bindir}
install -Dm0755 build/bin/cargo %{buildroot}%{_bindir}/cargo
mkdir -p %{buildroot}%{_mandir}/man1
install -Dm0644 src/etc/man/cargo*.1 %{buildroot}%{_mandir}/man1/
install -Dm0644 src/etc/cargo.bashcomp.sh %{buildroot}%{_sysconfdir}/bash_completion.d/cargo.sh

%files
%defattr(-,root,root)
%doc LICENSE-APACHE LICENSE-MIT README.md
%{_bindir}/cargo
%doc %{_mandir}/man1/*
%config %{_sysconfdir}/bash_completion.d/cargo.sh

%changelog
* Fri Apr 28 2017 luke.nukem.jones@gmail.com
- Update to 0.18.0
  * [The `cargo check` command does a type check of a project without
  building it][cargo/3296]
  * [crates.io will display CI badges from Travis and AppVeyor, if
  specified in Cargo.toml][cargo/3546]
  * [crates.io will display categories listed in Cargo.toml][cargo/3301]
  * [Compilation profiles accept integer values for `debug`, in addition
  to `true` and `false`. These are passed to `rustc` as the value to
  `-C debuginfo`][cargo/3534]
  * [Implement `cargo --version --verbose`][cargo/3604]
  * [All builds now output 'dep-info' build dependencies compatible with
  make and ninja][cargo/3557]
  * [Build all workspace members with `build --all`][cargo/3511]
  * [Document all workspace members with `doc --all`][cargo/3515]
  * [Path deps outside workspace are not members][cargo/3443]
- Restrict version required for building
* Fri Mar 17 2017 luke.nukem.jones@gmail.com
- Remove reproducible.patch - has been upstreamed.
* Fri Mar 17 2017 luke.nukem.jones@gmail.com
- Update to 0.17.0
  * [The `cargo check` command does a type check of a project without
  building it][cargo/3296]
  * [crates.io will display CI badges from Travis and AppVeyor, if
  specified in Cargo.toml][cargo/3546]
  * [crates.io will display categories listed in Cargo.toml][cargo/3301]
  * [Compilation profiles accept integer values for `debug`, in addition
  to `true` and `false`. These are passed to `rustc` as the value to
  `-C debuginfo`][cargo/3534]
  * [Implement `cargo --version --verbose`][cargo/3604]
  * [All builds now output 'dep-info' build dependencies compatible with
  make and ninja][cargo/3557]
  * [Build all workspace members with `build --all`][cargo/3511]
  * [Document all workspace members with `doc --all`][cargo/3515]
  * [Path deps outside workspace are not members][cargo/3443]
* Wed Feb 15 2017 luke.nukem.jones@gmail.com
- Fixes to build for archs armv7, aarch64, ppc64, s390x
* Thu Feb  9 2017 luke.nukem.jones@gmail.com
- Update to 0.16.0
  * No changelog provided by upstream
* Tue Jan 31 2017 luke.nukem.jones@gmail.com
- Update to 0.15.0
  * [In this release, Cargo build scripts no longer have access to the `OUT_DIR`
    environment variable at build time via `env!("OUT_DIR")`][cargo/3368]. They
    should instead check the variable at runtime with `std::env`. That the value
    was set at build time was a bug, and incorrect when cross-compiling. This
    change is known to cause breakage.
  * [Add `--all` flag to `cargo test`][cargo/3221]
  * [Compile statically against the MSVC CRT][cargo/3363]
  * [Mix feature flags into fingerprint/metadata shorthash][cargo/3102]
  * [Link OpenSSL statically on OSX][cargo/3311]
  * [Apply new fingerprinting to build dir outputs][cargo/3310]
  * [Test for bad path overrides with summaries][cargo/3336]
  * [Require `cargo install --vers` to take a semver version][cargo/3338]
  * [Fix retrying crate downloads for network errors][cargo/3348]
  * [Implement string lookup for `build.rustflags` config key][cargo/3356]
  * [Emit more info on --message-format=json][cargo/3319]
  * [Assume `build.rs` in the same directory as `Cargo.toml` is a build script][cargo/3361]
  * [Don't ignore errors in workspace manifest][cargo/3409]
  * [Fix `--message-format JSON` when rustc emits non-JSON warnings][cargo/3410]
* Tue Jan 17 2017 bwiedemann@suse.com
- Add reproducible.patch to allow for reproducible builds
* Thu Nov  3 2016 matwey.kornilov@gmail.com
- Update to 0.13.0
  * This release includes security fixes to both curl and OpenSSL.
  * [Fix transitive doctests when panic=abort][cargo/3021]
  * [Add --all-features flag to cargo][cargo/3038]
  * [Reject path-based dependencies in `cargo package`][cargo/3060]
  * [Don't parse the home directory more than once][cargo/3078]
  * [Don't try to generate Cargo.lock on empty workspaces][cargo/3092]
  * [Update OpenSSL to 1.0.2j][cargo/3121]
  * [Add license and license_file to cargo metadata output][cargo/3110]
  * [Make crates-io registry URL optional in config; ignore all changes to
    source.crates-io][cargo/3089]
  * [Don't download dependencies from other platforms][cargo/3123]
  * [Build transitive dev-dependencies when needed][cargo/3125]
  * [Add support for per-target rustflags in .cargo/config][cargo/3157]
  * [Avoid updating registry when adding existing deps][cargo/3144]
  * [Warn about path overrides that won't work][cargo/3136]
  * [Use workspaces during `cargo install`][cargo/3146]
  * [Leak mspdbsrv.exe processes on Windows][cargo/3162]
  * [Add --message-format flag][cargo/3000]
  * [Pass target environment for rustdoc][cargo/3205]
  * [Use `CommandExt::exec` for `cargo run` on Unix][cargo/2818]
  * [Update curl and curl-sys][cargo/3241]
  * [Call rustdoc test with the correct cfg flags of a package][cargo/3242]
* Wed Aug 10 2016 kgronlund@suse.com
- Update to 0.11.0
  * Fix compilation using rustc 1.10
  * Implement the `panic` profile option
  * Don't throw away errors with `-p` arguments
* Sun Jul  3 2016 kgronlund@suse.com
- Revised packaging to rely on cargo-vendor
* Wed Jun 29 2016 kgronlund@suse.com
- Update to 0.10.0
- Revised packaging to rely on cargo-bootstrap project when building
* Sun Apr 17 2016 mvyskocil@opensuse.org
- Update to 0.9.0
* Wed Feb 10 2016 mvyskocil@opensuse.org
- Adapted version (per review request)
* Thu Jan 28 2016 mvyskocil@opensuse.org
- Initial packaging of cargo for openSUSE
